.. blochwave documentation master file, created by
   sphinx-quickstart on Mon Nov 22 11:52:41 2021.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to ccp4-ed documentation!
=====================================

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   reference
   examples


Indices and tables
==================

* :ref:`genindex`
* :ref:`search`
